function [x,res]=GaussSeidel(A,b,x0,tol,maxiter)
% GAUSSSEIDEL Resolution of linear systems by Gauss-Seidel
%   [x,res]=GAUSSSEIDEL(A,b,x0,tol,maxiter) solves Ax=b by
%   Gauss-Seidel using x0 as initial guess. The algorithm 
%   stops when maxiter operations have been performed, or when the L2 norm of  
%   residual becomes smaller than tol. The output x is the approximation of the
%   solution, and res is a vector containing the history of the residuals.

if(nargin <2)
  error('not enough arguments');
end
if(nargin < 5) 
  maxiter=500; 
end
if(nargin <4)
  tol=1e-6;
end
if(nargin <3)
   x0=zeros(size(A,1),1);
end


L=tril(A,-1);
U=triu(A,1);
D=diag(diag(A));

x=x0;

res(1)=norm(b-A*x,inf);

i=1;
while(i<=maxiter & res(i)>tol)
%while(i<=maxiter) % to see the behavior of the iterations 
x=(D+L)\(-U*x+b);
res(i+1)=norm(b-A*x,inf);
i=i+1;
end

