function [x,res]=Jacobi(A,b,x0,tol,maxiter)
% JACOBI  Resolution of linear systems by Jacobi method.
%   [x,res]=JACOBI(A,b,x0,tol,maxiter) solves Ax=b by
%   Jacobi using x0 as initial guess. The algorithm 
%   stops when maxiter operations have been performed, or when the L2 norm of  
%   residual becomes smaller than tol. The output x is the approximation of the
%   solution, and res is a vector containing the history of the residuals.
if(nargin <2)
  error('not enough arguments');
end
if(nargin < 5) 
  maxiter=500; 
end
if(nargin <4)
  tol=1e-6;
end
if(nargin <3)
   x0=zeros(size(A,1),1);
end


E=-tril(A,-1);
F=-triu(A,1);
D=diag(A);

x=x0;

res(1)=norm(b-A*x,inf);

i=1;
while(i<=maxiter & res(i)>tol)
%while(i<=maxiter) % to see the behavior of the iterations 
    x=((E+F)*x+b)./D;
    res(i+1)=norm(b-A*x,inf);
    i=i+1;
end
