function [x,res]=Richardson(A,b,alpha,x0,tol,maxiter)
% Richardson Resolution of linear systems by Richardson
%   [x,res]=Richardson(A,b,relax,x0,tol,maxiter) solves Ax=b by 
%   Richardson with parameter relax  using x0 as initial guess. The algorithm 
%   stops when maxiter operations have been performed, or when the L2 norm of  
%   residual becomes smaller than tol. The output x is the approximation of the
%   solution, and res is a vector containing the history of the residuals.



if nargin <3 
  error('not enough arguments');
end
if nargin < 6 
  maxiter=500; 
end
if nargin <5
  tol=1e-6;
end
if nargin <4 
   x0=zeros(size(A,1),1);
end

x=x0;

res(1)=norm(b-A*x,inf);

i=1;
while i<=maxiter & res(i)>tol
%while(i<=maxiter) % to see the behavior of the iterations 
  x=(eye(size(A))-alpha*A)*x+alpha*b;
  res(i+1)=norm(b-A*x,inf);
  i=i+1;
end

